import React, { useState } from 'react';
import { View, Text, Image, StyleSheet, TouchableOpacity } from 'react-native';
import ActionSheet from 'react-native-actions-sheet';
import { Colors } from 'src/theme';
import { Ionicons } from '@expo/vector-icons';
import { API_HOST } from 'src/constants';
import { getFontSize } from 'src/utils';
import { useSafeAreaInsets } from 'react-native-safe-area-context';
import { ChatProps } from '../types';
import { useNavigation } from '@react-navigation/native';
import { NAVIGATION_PAGES } from 'src/types';

const MoreModal = () => {
  const insets = useSafeAreaInsets();
  const navigation = useNavigation();

  const [chatData, setChatData] = useState<ChatProps | null>(null);

  const handleSheetOpen = (payload: ChatProps | null) => {
    setChatData(payload);
  };

  return (
    <ActionSheet
      id="more-modal"
      gestureEnabled={true}
      onBeforeShow={(sheetRef) => {
        const payload = sheetRef || null;
        handleSheetOpen(payload);
      }}
      containerStyle={styles.sheetContainer}
      defaultOverlayOpacity={0.5}
      indicatorStyle={{ backgroundColor: 'transparent' }}
    >
      {chatData && (
        <View style={[styles.container, { paddingBottom: 8 + insets.bottom }]}>
          <TouchableOpacity
            style={styles.header}
            onPress={() =>
              navigation.navigate(
                ...([NAVIGATION_PAGES.PUBLIC_PROFILE_VIEW, { userId: chatData.id }] as never)
              )
            }
          >
            <Image source={{ uri: API_HOST + chatData?.avatar }} style={styles.avatar} />
            <Text style={styles.name}>{chatData.name}</Text>
          </TouchableOpacity>

          <View style={styles.optionsContainer}>
            <TouchableOpacity style={styles.option}>
              <Text style={styles.optionText}>Mute</Text>
              <Ionicons name="notifications-off-outline" size={18} color={Colors.DARK_BLUE} />
            </TouchableOpacity>
          </View>

          <View style={[styles.optionsContainer, { paddingVertical: 0, gap: 0 }]}>
            <TouchableOpacity style={[styles.option, styles.dangerOption]}>
              <Text style={[styles.optionText, styles.dangerText]}>Block {chatData.name}</Text>
              <Ionicons name="ban-outline" size={18} color={Colors.RED} />
            </TouchableOpacity>

            <TouchableOpacity style={[styles.option, styles.dangerOption]}>
              <Text style={[styles.optionText, styles.dangerText]}>Delete chat</Text>
              <Ionicons name="trash-outline" size={18} color={Colors.RED} />
            </TouchableOpacity>
          </View>
        </View>
      )}
    </ActionSheet>
  );
};

const styles = StyleSheet.create({
  sheetContainer: {
    borderTopLeftRadius: 15,
    borderTopRightRadius: 15
  },
  container: {
    backgroundColor: 'white',
    paddingHorizontal: 16,
    paddingTop: 8,
    gap: 16
  },
  header: {
    flexDirection: 'row',
    alignItems: 'center',
    borderBottomWidth: 1,
    borderBottomColor: Colors.FILL_LIGHT,
    gap: 8
  },
  avatar: {
    width: 32,
    height: 32,
    borderRadius: 16,
    borderWidth: 1,
    borderColor: Colors.FILL_LIGHT
  },
  name: {
    fontSize: getFontSize(14),
    fontFamily: 'montserrat-700',
    color: Colors.DARK_BLUE
  },
  optionsContainer: {
    paddingVertical: 10,
    paddingHorizontal: 8,
    gap: 16,
    borderRadius: 8,
    backgroundColor: Colors.FILL_LIGHT
  },
  option: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between'
  },
  optionText: {
    fontSize: getFontSize(12),
    fontWeight: '600',
    color: Colors.DARK_BLUE
  },
  dangerOption: {
    paddingVertical: 10,
    borderBottomWidth: 1,
    borderBlockColor: Colors.WHITE
  },
  dangerText: {
    color: Colors.RED
  }
});

export default MoreModal;
