import React, { useEffect, useState } from 'react';
import {
  View,
  TextInput,
  Text,
  Image,
  TouchableOpacity,
  StyleSheet,
  ActivityIndicator,
  Platform
} from 'react-native';
import ActionSheet from 'react-native-actions-sheet';
import { FlashList } from '@shopify/flash-list';
import { storage, StoreType } from 'src/storage';
import { usePostSearchUsers } from '@api/chat';
import { API_HOST } from 'src/constants';
import { Colors } from 'src/theme';
import { useNavigation } from '@react-navigation/native';
import { NAVIGATION_PAGES } from 'src/types';

const SearchModal = () => {
  const navigation = useNavigation();
  const token = storage.get('token', StoreType.STRING) as string;
  const [searchQuery, setSearchQuery] = useState('');
  const { data: searchResult, isFetching } = usePostSearchUsers(
    token,
    searchQuery,
    searchQuery.length > 1
  );

  useEffect(() => {}, [searchResult]);

  const renderItem = ({ item }: { item: any }) => (
    <TouchableOpacity
      style={styles.itemContainer}
      onPress={() =>
        navigation.navigate(
          ...([
            NAVIGATION_PAGES.CHAT,
            {
              id: item.user_id,
              name: item.first_name + ' ' + item.last_name,
              avatar: item.avatar
            }
          ] as never)
        )
      }
    >
      <Image source={{ uri: API_HOST + item.avatar }} style={styles.avatar} />
      <View style={styles.textContainer}>
        <Text style={styles.name}>
          {item.first_name} {item.last_name}
        </Text>
      </View>
    </TouchableOpacity>
  );

  return (
    <ActionSheet
      id="search-modal"
      gestureEnabled={Platform.OS === 'ios'}
      onClose={() => setSearchQuery('')}
      containerStyle={styles.sheetContainer}
      defaultOverlayOpacity={0.5}
      indicatorStyle={{ backgroundColor: 'transparent' }}
    >
      <View style={styles.container}>
        <TextInput
          style={styles.searchInput}
          placeholder="Search nomads"
          value={searchQuery}
          onChangeText={(text) => {
            setSearchQuery(text);
          }}
        />

        {isFetching ? (
          <ActivityIndicator size="large" color="#0000ff" />
        ) : (
          <View style={{ flex: 1 }}>
            <FlashList
              viewabilityConfig={{
                waitForInteraction: true,
                itemVisiblePercentThreshold: 50,
                minimumViewTime: 1000
              }}
              data={searchResult?.data || []}
              renderItem={renderItem}
              keyExtractor={(item) => item.user_id.toString()}
              estimatedItemSize={100}
              extraData={searchResult}
              showsVerticalScrollIndicator={false}
              refreshing={isFetching}
            />
          </View>
        )}
      </View>
    </ActionSheet>
  );
};

const styles = StyleSheet.create({
  sheetContainer: {
    height: '80%',
    borderTopLeftRadius: 15,
    borderTopRightRadius: 15,
    paddingHorizontal: 16
  },
  container: {
    backgroundColor: 'white',
    gap: 12,
    height: '100%'
  },
  searchInput: {
    height: 40,
    borderColor: '#ccc',
    borderWidth: 1,
    borderRadius: 8,
    paddingHorizontal: 10,
    marginBottom: 10
  },
  itemContainer: {
    flexDirection: 'row',
    alignItems: 'center',
    paddingVertical: 10,
    borderBottomColor: '#ccc',
    borderBottomWidth: 1
  },
  avatar: {
    width: 48,
    height: 48,
    borderRadius: 24,
    borderWidth: 1,
    borderColor: Colors.FILL_LIGHT,
    marginRight: 15
  },
  textContainer: {
    flex: 1
  },
  name: {
    fontSize: 16,
    fontWeight: 'bold'
  }
});

export default SearchModal;
